@@ -49,9 +49,9 @@
 #'    ylab = "Relative Expression",
 #'    xlab = "Drought Levels",
 #'    show.letters = TRUE, 
-#'    letter.position.adjust = 0.3,
-#'    legend.position = c(0.09, 0.8),
-#'    errorbar = "ci")
+#'    letter.position.adjust = 0.2,
+#'    legend.position = c(0.2, 0.8),
+#'    errorbar = "se")
 #'
 #' # Plotting the same data with 'Drought' as grouping factor
 #' twoFACTORplot(res,
@@ -160,7 +160,7 @@ twoFACTORplot <- function(res,
   
   if (show.errorbars) {
     qq2 <-qq2 +
-      geom_errorbar(aes(ymin = RE - UCL, ymax = RE + LCL), width = 0.2, position = position_dodge(width = 0.5))
+      geom_errorbar(aes(ymin = LCL, ymax = UCL), width = 0.2, position = position_dodge(width = 0.5))
   }
   
   if (show.points) {
@@ -171,7 +171,7 @@ twoFACTORplot <- function(res,
   }
   if (show.letters) {
     qq2 <- qq2 + 
-      geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = RE + LCL + letter.position.adjust), 
+      geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = UCL + letter.position.adjust), 
                 vjust = -0.5, size = fontsizePvalue, position = position_dodge(width = 0.5))
   }
   
